# cmempy

cmempy is a Python API wrapper for [eccenca Corporate Memory](https://documentation.eccenca.com/).

## Installation

To install the Python library run:

    pip install cmem-cmempy

You may consider installing the package only for the current user:

    pip install cmem-cmempy --user

## Configuration and Usage

cmempy is intended for Linked Data Experts to interface with the eccenca Corporate Memory backend components DataIntegration and DataPlatform.

The cmempy manual including basic usage patterns and configuration is available at:

[https://eccenca.com/go/cmempy](https://eccenca.com/go/cmempy)

cmempy is tests with python 3.9 and 3.11.

